@startuml

AgentPipeline -down-* PipelineContainer
class AgentPipeline {
    + container : PipelineContainer
}


' PipelineContainer *-up- AgentPipeline
PipelineContainer "1" -right- "1..*" PipelineComponent : contains
class PipelineContainer {
    + pipeline : AgentPipeline
    + pipelineComponents : Array<PipelineComponent>
    + components : Array<PipelineComponent>
}


PipelineComponent "1" -right-> "1" Agent : uses
' PipelineComponent -- PipelineContainer
class PipelineComponent {
    + pipelineComponentId : UUID
    + type : String
    + container : PipelineContainer
    + agent : Agent
}



Agent "1" -right- "1" AgentConfig
interface Agent {
    + agentId : UUID
    + name : String
    + description : String
    + update() : JSON
}
' DefaultAgent .up.|> Agent


AgentConfig "1" -right-> "1" AIModelSession

' AgentConfig -- Agent
interface AgentConfig {
    + agentConfig : JSON
    + aiModelSession : AIModelSession
}


DefaultAgent .up.|> Agent
class DefaultAgent {
    + agentId : UUID
    + name : String
    + description : String
    + config : AgentConfig
}

class SessionConfigAdapter as "Session Config Adapter"
SessionConfigAdapter .up.|> SessionConfig



' AIModelSession ..up.|> Session
interface Session {
    + sessionId : UUID
    + config : SessionConfig
}
Session "1" -right-> "1" SessionConfig


' SessionConfig -- Session
interface SessionConfig {
    + config : JSON
}
' AIModelSessionConfig .up.|> SessionConfig
' GeminiSessionConfig .up.|> SessionConfig
' GrokSessionConfig ..up.|> SessionConfig
' SessionConfigAdapter .up.|> SessionConfig



interface RequestConfig {
    + config : JSON
}

' interface ResponseConfig {
'     + response : JSON
' }

interface ResponseSchema {
    + schema : JSON
}










AIModel .up.|> LLM
AIModel "1" -----down- "1" AIModelSession
class AIModel {
    - apiKey : String

    + modelId : UUID
    + type : String
    + url : URL
    + session : AIModelSession
}
' Gemini --up-|> AIModel
' Grok ----up-|> AIModel


AIModelSession ..up.|> Session
AIModelSession "1" -right- "1" AIModelSessionConfig
' AIModelSession -- AIModel
class AIModelSession {
    + model : AIModel
    + config : AIModelSessionConfig
}
' GeminiSession .up.|> AIModelSession
' GrokSession ..up.|> AIModelSession



AIModelSessionConfig .up.|> SessionConfig
' AIModelSessionConfig -- AIModelSession
AIModelSessionConfig "1" -right- "1" RequestConfig
AIModelSessionConfig "1" -right- "1" ResponseSchema
class AIModelSessionConfig {
    + session : AIModelSession
    + request : RequestConfig
    + schema : ResponseSchema
}
' GeminiSessionConfig .up.|> AIModelSessionConfig
' GrokSessionConfig ..up.|> AIModelSessionConfig



' Gemini .up.|> LLM
Gemini ------up-|> AIModel
Gemini "1" -right- "1" GeminiSession
Gemini "1" --down- "1" GeminiClient
class Gemini {
    - geminiClient : GeminiClient
    + session : GeminiSession
}

class ESMModule


GeminiClient --up-|> ESMModule
class GeminiClient {
    + config : GeminiSessionConfig
}

GeminiSession .up.|> AIModelSession
' GeminiSession -- Gemini
GeminiSession -right-> GeminiSessionConfig
class GeminiSession {
    + model : Gemini
    + config : GeminiSessionConfig
}


GeminiSessionConfig .up.|> AIModelSessionConfig
' GeminiSessionConfig -- GeminiSession
class GeminiSessionConfig {
    + session : GeminiSession
}


' Grok ...up.|> LLM
Grok -------up-|> AIModel
Grok "1" -right- "1" GrokSession
Grok "1" -down- "1" GrokClient
class Grok {
    - grokClient : GrokClient
    + session : GrokSession
}






' GrokClient ...up.|> LLM
GrokClient --up-|> ESMModule
class GrokClient {
    + config : GrokSessionConfig
}


GrokSession ..up.|> AIModelSession
' GrokSession -- Grok
GrokSession --right-> GrokSessionConfig
class GrokSession {
    + model : Grok
    + config : GrokSessionConfig
}

GrokSessionConfig ..up.|> AIModelSessionConfig
class GrokSessionConfig {
    + session : GrokSession
}

' AIModel .up.|> LLM
' Gemini .up.|> LLM
' Grok ...up.|> LLM
interface LLM {
    + llmId : UUID
    + name : String
    + description : String
    + process(request : RequestConfig, config : AIModelConfig) : ResponseConfig
}


@enduml